@@ -63,6 +63,9 @@
 #include <glib.h>
 
 #include "hildon-file-common-private.h"
+
+#define DEBUG
+
 #define HILDON_RESPONSE_FOLDER_BUTTON 12345
 #define HILDON_RESPONSE_FOLDER_CREATED 54321
 /* Common height for filetrees. About 8 lines. Filetree sets default margins,
@@ -73,6 +76,12 @@
 #define FILE_SELECTION_WIDTH_TOTAL 590  /* Width for full filetree (both
                                            content and navigation pane) */
 
+#ifdef DEBUG
+#define DBG(args...) fprintf (stderr, ## args)
+#else
+#define DBG(...) do { } while (0)
+#endif
+
 static void sync_extensions_combo (HildonFileChooserDialogPrivate *priv);
 
 #define HILDON_FILE_CHOOSER_DIALOG_TYPE_SELECTION_MODE (hildon_file_chooser_dialog_selection_mode_get_type())
@@ -355,11 +364,21 @@ hildon_file_chooser_dialog_save_multiple_set(HildonFileChooserDialogPrivate *pri
   return text && strlen(text) > 0;
 }
 
-static void
+/* 
+   Sets content to name entry. 
+   Returns TRUE if content has changed, FALSE if not 
+*/ 
+static gboolean
 set_entry (GtkWidget *entry, const char *name, const char *ext)
 {
   if (name == NULL)
-    return;
+    return FALSE;
+
+  gchar *orig_name = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+  const gchar *new_name;
+  gboolean retval;
+
+  DBG ("SET ENTRY '%s' '%s'\n", name, ext);
 
   gtk_entry_set_text (GTK_ENTRY(entry), name);
 
@@ -374,6 +393,17 @@ set_entry (GtkWidget *entry, const char *name, const char *ext)
                                 ext, strlen (ext),
                                 &position);
     }
+
+  new_name = gtk_entry_get_text (GTK_ENTRY (entry));
+
+  if (strcmp (new_name, orig_name) == 0)
+	retval = FALSE;
+  else
+    retval = TRUE;
+
+  g_free (orig_name);
+  return retval;
+
 }
 
 static gchar *
@@ -405,52 +435,50 @@ hildon_file_chooser_dialog_do_autonaming(HildonFileChooserDialogPrivate *
                                          priv)
 {
     g_assert(HILDON_IS_FILE_SELECTION(priv->filetree));
+	
+	gboolean changed;
 
     if (GTK_WIDGET_VISIBLE(priv->caption_control_name) &&
         priv->stub_name && priv->stub_name[0] && !priv->edited)
     {
         gchar *name = NULL;
-        gboolean selection;
-        gint pos;
 
         g_signal_handler_block(priv->entry_name, priv->changed_handler);
         if (priv->autonaming_enabled) {
             GtkTreeIter iter;
 
-            ULOG_INFO("Trying [%s] [%s]", priv->stub_name, priv->ext_name);
+            DBG ("Trying [%s] [%s]\n", priv->stub_name, priv->ext_name);
             if (hildon_file_selection_get_current_folder_iter
                 (priv->filetree, &iter)) {
                 name =
                     hildon_file_system_model_new_item(priv->model, &iter,
                                                       priv->stub_name,
                                                       priv->ext_name);
-                ULOG_INFO("Got [%s]", name);
+                DBG ("Got [%s]\n", name);
             }
         }
 
-        pos = gtk_editable_get_position(GTK_EDITABLE(priv->entry_name));
-        selection =
-          gtk_editable_get_selection_bounds(GTK_EDITABLE(priv->entry_name),
-                                            NULL, NULL);
-
         if (name)
         {
-          gboolean edited = !selection &&
-                               (pos != g_utf8_strlen (gtk_entry_get_text(GTK_ENTRY(priv->entry_name)), -1));
-          set_entry (priv->entry_name, name, priv->ext_name);
+          changed = set_entry (priv->entry_name, name, priv->ext_name);
           g_free(name);
-          if (!edited)
-            gtk_editable_select_region(GTK_EDITABLE(priv->entry_name), 0, -1);
-          else
-            /* if the user has already started to edit the name,
-               try to preserve cursor position and don't autoselect */
-            gtk_editable_set_position(GTK_EDITABLE(priv->entry_name), pos);
-        }
+		}
         else
-          set_entry (priv->entry_name, priv->stub_name, priv->ext_name);
+          changed = set_entry (priv->entry_name, priv->stub_name, priv->ext_name);
 
         g_signal_handler_unblock(priv->entry_name, priv->changed_handler);
     }
+    else
+      changed = set_entry (priv->entry_name, priv->stub_name, priv->ext_name);
+
+	if (changed) {
+    	gtk_editable_select_region(GTK_EDITABLE(priv->entry_name), 0, -1);
+		if (!gtk_widget_is_focus(GTK_WIDGET (priv->entry_name))) {
+			gtk_widget_grab_focus (GTK_WIDGET (priv->entry_name));
+		}
+	}
+
+    return;
 }
 
 /* Set PRIV->stub_name and PRIV->ext_name from NAME so that stub_name
@@ -468,6 +496,8 @@ set_stub_and_ext (HildonFileChooserDialogPrivate *priv,
   char *dot;
   gboolean is_folder;
 
+  DBG ("SET STUB AND EXT %s\n", name);
+
   g_free (priv->stub_name);
   g_free (priv->ext_name);
   priv->stub_name = g_strdup (name);
@@ -739,8 +769,6 @@ static void hildon_file_chooser_dialog_set_current_name(GtkFileChooser *
     ULOG_INFO("Current name set: body = %s, ext = %s", priv->stub_name, priv->ext_name);
     hildon_file_chooser_dialog_set_limit(HILDON_FILE_CHOOSER_DIALOG(chooser));
     hildon_file_chooser_dialog_do_autonaming(priv);
-
-    set_entry (priv->entry_name, priv->stub_name, priv->ext_name);
 }
 
 static gboolean hildon_file_chooser_dialog_select_path(GtkFileChooser *
@@ -1217,6 +1245,7 @@ static void handle_folder_popup(HildonFileChooserDialog *self)
   GtkFileSystem *backend;
   GtkWidget *dialog;
   gint response;
+  gchar *uri = NULL;
 
   g_return_if_fail(HILDON_IS_FILE_CHOOSER_DIALOG(self));
 
@@ -1234,8 +1263,9 @@ static void handle_folder_popup(HildonFileChooserDialog *self)
   if (self->priv->edited)
   {
     self->priv->edited = FALSE;
-    hildon_file_chooser_dialog_set_current_name(GTK_FILE_CHOOSER(self),
-      gtk_entry_get_text(GTK_ENTRY(self->priv->entry_name)));
+    hildon_file_chooser_dialog_set_current_name 
+      (GTK_FILE_CHOOSER(self),
+       get_entry (self->priv->entry_name, self->priv->ext_name));
   }
 
   backend = _hildon_file_system_model_get_file_system(self->priv->model);
@@ -1249,8 +1279,6 @@ static void handle_folder_popup(HildonFileChooserDialog *self)
 
     while ((response = gtk_dialog_run(GTK_DIALOG(dialog))) == GTK_RESPONSE_OK)
     {
-      gchar *uri;
-
       uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
       ULOG_INFO_F("About to create folder %s", uri);
 
@@ -1273,8 +1301,6 @@ static void handle_folder_popup(HildonFileChooserDialog *self)
                                        create_folder_callback,
                                        g_object_ref(dialog));
 
-      g_free(uri);
-
       /* Make OK button insensitive while folder operation is going */
       gtk_dialog_set_response_sensitive
         (GTK_DIALOG(dialog), GTK_RESPONSE_OK, FALSE);
@@ -1289,8 +1315,11 @@ static void handle_folder_popup(HildonFileChooserDialog *self)
     if (response == HILDON_RESPONSE_FOLDER_CREATED)
       {
         g_assert(file_path != NULL);
-        hildon_file_chooser_dialog_set_current_folder
-          (GTK_FILE_CHOOSER(self), file_path, NULL);
+        if (!hildon_file_chooser_dialog_set_current_folder
+          (GTK_FILE_CHOOSER(self), file_path, NULL) && uri) {
+			hildon_file_selection_move_cursor_to_uri (self->priv->filetree, 
+														uri);
+		}
       }
     gtk_file_path_free(file_path);
   }
@@ -1306,6 +1335,7 @@ static void handle_folder_popup(HildonFileChooserDialog *self)
   gtk_widget_destroy(dialog);
   gtk_window_present(GTK_WINDOW(self));
   self->priv->popup_protect = FALSE;
+  g_free(uri);
 }
 
 static gboolean hildon_file_chooser_dialog_location_pressed(GtkWidget
@@ -1378,13 +1408,12 @@ static void response_handler(GtkWidget * widget, gint arg1, gpointer data)
 
                     if (path_length > self->priv->max_full_path_length)
                     {
-                        GtkWidget *w;
                         g_signal_stop_emission_by_name(widget, "response");
                         hildon_file_chooser_dialog_select_text(priv);
-                        w = hildon_note_new_information(GTK_WINDOW(widget),
-                                FM("sfil_ni_target_foldername_long"));
-                        gtk_dialog_run(GTK_DIALOG(w));
-                        gtk_widget_destroy(w);
+                    	hildon_banner_show_information (widget, NULL,
+							dgettext("hildon-common-strings",
+								"file_ib_name_too_long"));
+
                     }
                     g_free(uri);
                 }
