@@ -99,6 +99,8 @@ hildon_file_system_root_create_child_location (HildonFileSystemSpecialLocation
     {
       child = g_object_new (HILDON_TYPE_FILE_SYSTEM_VOLDEV, NULL);
       child->basepath = g_strdup (uri);
+      child->permanent = FALSE;
+      hildon_file_system_special_location_volumes_changed (child, NULL);
     }
 
   return child;
@@ -226,6 +228,7 @@ root_file_folder_list_children (GtkFileFolder  *folder,
                                       gtk_file_system_uri_to_path (fs, uri));
         }
     }
+  g_list_foreach (volumes, (GFunc) g_object_unref, NULL);
   g_list_free (volumes);
 
   drives = gnome_vfs_volume_monitor_get_connected_drives (monitor);
@@ -243,6 +246,7 @@ root_file_folder_list_children (GtkFileFolder  *folder,
           g_free (uri);
         }
     }
+  g_list_foreach (drives, (GFunc) g_object_unref, NULL);
   g_list_free (drives);
 
   return TRUE;
