@@ -160,7 +160,6 @@ static gboolean
 hildon_file_system_smb_is_visible (HildonFileSystemSpecialLocation *location,
 				   gboolean has_children)
 {
-  fprintf (stderr, "SMB VISIBLE (%d)\n", has_children);
   if (!has_children)
     return FALSE;
   else
@@ -187,7 +186,6 @@ hildon_file_system_smb_get_folder (HildonFileSystemSpecialLocation *location,
                                    GtkFileSystemGetFolderCallback  callback,
                                    gpointer                        data)
 {
-  fprintf (stderr, "SMB GETFOLDER\n");
   return hildon_file_system_smb_get_workgroups_folder (file_system,
                                                        path,
                                                        types,
@@ -315,8 +313,6 @@ my_file_folder_list_children (GtkFileFolder  *folder,
   MyFileFolder *my_folder = MY_FILE_FOLDER (folder);
   GList *c;
 
-  fprintf (stderr, "SMB GOT CHILDREN (%d)\n", g_slist_length (*children));
-
   *children = NULL;
   for (c = my_folder->children; c; c = c->next)
     {
@@ -330,8 +326,6 @@ my_file_folder_list_children (GtkFileFolder  *folder,
       *children = g_slist_append (*children, childrens_children);
     }
 
-  fprintf (stderr, "SMB GOT CHILDREN (%d)\n", g_slist_length (*children));
-
   return TRUE;
 }
 
@@ -341,8 +335,6 @@ my_file_folder_is_finished_loading (GtkFileFolder *folder)
   MyFileFolder *my_folder = MY_FILE_FOLDER (folder);
   GList *c;
 
-  fprintf (stderr, "SMB FINISHED\n");
-
   if (!gtk_file_folder_is_finished_loading (GTK_FILE_FOLDER (my_folder->root)))
     return FALSE;
 
@@ -355,7 +347,6 @@ my_file_folder_is_finished_loading (GtkFileFolder *folder)
         return FALSE;
     }
 
-  fprintf (stderr, "SMB TRUE\n");
   return TRUE;
 }
 
@@ -409,8 +400,6 @@ my_file_folder_child_files_added (GtkFileFolder *folder,
       GtkFilePath *p = paths->data;
       GtkFilePath *my_p = my_file_folder_collaps_path (p);
 
-      fprintf (stderr, "SMB CHILD %s\n", gtk_file_path_get_string (my_p));
-
       my_paths = g_slist_append (my_paths, my_p);
       paths = paths->next;
     }
@@ -435,8 +424,6 @@ my_file_folder_child_folder_added (GtkFileSystemHandle *handle,
 
   g_object_unref (handle);
 
-  fprintf (stderr, "SMB CHILD FOLDER %p\n", folder);
-
   if (folder)
     {
       my_folder->children = g_list_append (my_folder->children,
@@ -459,7 +446,6 @@ my_file_folder_root_files_added (GtkFileFolder *folder,
   while (paths)
     {
       GtkFilePath *p = paths->data;
-      fprintf (stderr, "SMB ROOT %s\n", gtk_file_path_get_string (p));
       my_folder->n_children_waiting++;
       gtk_file_system_get_folder (my_folder->filesystem,
                                   p,
